summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pminsertrulesystem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pminsertrulesystem.h')
-rw-r--r--kpovmodeler/pminsertrulesystem.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpovmodeler/pminsertrulesystem.h b/kpovmodeler/pminsertrulesystem.h
index 0f13a099..2559fdba 100644
--- a/kpovmodeler/pminsertrulesystem.h
+++ b/kpovmodeler/pminsertrulesystem.h
@@ -344,7 +344,7 @@ private:
};
/**
* Condition. Value is true if the object already tqcontains
* objects of certaint classes before the insert point.
*/
class PMRuleBefore : public PMRuleCondition
@@ -371,11 +371,11 @@ protected:
virtual void resetProtected( );
private:
TQPtrList<PMRuleCategory> m_categories;
- bool m_tqcontains;
+ bool m_contains;
};
/**
* Condition. Value is true if the object already tqcontains
* objects of certaint classes after the insert point.
*/
class PMRuleAfter : public PMRuleCondition
@@ -402,11 +402,11 @@ protected:
virtual void resetProtected( );
private:
TQPtrList<PMRuleCategory> m_categories;
- bool m_tqcontains;
+ bool m_contains;
};
/**
* Condition. Value is true if the object already tqcontains
* objects of certaint classes.
*/
class PMRuleContains : public PMRuleCondition
@@ -433,7 +433,7 @@ protected:
virtual void resetProtected( );
private:
TQPtrList<PMRuleCategory> m_categories;
- bool m_tqcontains;
+ bool m_contains;
};
/**
@@ -344,7 +344,7 @@ private:
};
/**
- * Condition. Value is true if the object already tqcontains
+ * Condition. Value is true if the object already contains
* objects of certaint classes before the insert point.
*/
@@ -371,11 +371,11 @@ protected:
};
/**
- * Condition. Value is true if the object already tqcontains
+ * Condition. Value is true if the object already contains
* objects of certaint classes after the insert point.
*/
@@ -402,11 +402,11 @@ protected:
};
/**
- * Condition. Value is true if the object already tqcontains
+ * Condition. Value is true if the object already contains
* objects of certaint classes.
*/